@@ -1,7 +1,7 @@
 (*********************************************************************************)
 (*                Cameleon                                                       *)
 (*                                                                               *)
-(*    Copyright (C) 2004-2010 Institut National de Recherche en Informatique     *)
+(*    Copyright (C) 2004-2011 Institut National de Recherche en Informatique     *)
 (*    et en Automatique. All rights reserved.                                    *)
 (*                                                                               *)
 (*    This program is free software; you can redistribute it and/or modify       *)
@@ -870,22 +870,30 @@ let detect_xml_light ?(modes=[`Byte;`Opt]) conf =
   iter includes
 (*/c==v=[OCaml_conf.detect_xml_light]=0.3====*)
 
-let detect_lablgtksourceview2 ?(modes=[`Byte;`Opt]) conf =
+let detect_lablgtkextras ?(modes=[`Byte;`Opt]) lablgtk_incs conf =
   let includes =
     ["default install",
-      List.map (Filename.concat (ocaml_libdir conf)) ["lablgtk2"]]
+      (Filename.concat (ocaml_libdir conf) "lablgtk-extras") :: lablgtk_incs
+    ]
   in
   let includes =
-    match ocamlfind_query conf "lablgtksourceview2" with
+    match ocamlfind_query conf "lablgtkextras" with
       None -> includes
     | Some s ->
-	match ocamlfind_query conf "lablgtksourceview2" with
+	match ocamlfind_query conf "lablgtkextras" with
 	  None -> includes
 	| Some s2 -> ("with ocamlfind", [s2;s]) :: includes
   in
-  let libs = ["lablgtk.cma" ; "lablgtksourceview2.cma"] in
+  let libs =
+    [ "unix.cma" ;
+      "lablgtk.cma" ;
+      "lablgtksourceview2.cma";
+      "config_file.cmo";
+      "xml-light.cma";
+      "lablgtkextras.cma"]
+  in
   let f (mes, includes) mode =
-    let mes = Printf.sprintf "checking for Lablgtksourceview2 (%s) %s... "
+    let mes = Printf.sprintf "checking for Lablgtk-extras (%s) %s... "
 	(string_of_mode mode) mes
     in
     can_link ~mes mode conf ~includes ~libs []
@@ -921,6 +929,27 @@ let detect_pcre ?(modes=[`Byte;`Opt]) conf =
       includes
 ;;
 
+let detect_sqlite3 ?(modes=[`Byte;`Opt]) conf =
+  match ocamlfind_query conf "sqlite3" with
+    None ->
+      !fatal_error (Printf.sprintf "ocaml-sqlite3 could not be found with ocamlfind.");
+      []
+  | Some d ->
+      let includes = [d] in
+      let f mode =
+        let mes = Printf.sprintf "checking for ocaml-sqlite3 (%s)... "
+            (string_of_mode mode)
+        in
+        if can_link ~mes mode conf ~includes ~libs: ["sqlite3.cma"] [] then
+          ()
+        else
+          !fatal_error (Printf.sprintf "Could not link with ocaml-sqlite3 (%s)"
+           (string_of_mode mode))
+      in
+      List.iter f modes;
+      includes
+;;
+
 let ocaml_required = [3;9;1]
 let conf = ocaml_conf ();;
 print_conf conf;;
@@ -948,6 +977,16 @@ let pcre_includes =
 let _ = add_subst "PCRE_INCLUDES" (string_of_includes pcre_includes)
 let _ = add_subst "PCREDIR" (List.hd pcre_includes)
 
+(*
+let sqlite3_includes =
+  match detect_sqlite3 ~modes conf with
+    [] -> failwith "ocaml-sqlite3 not found."
+  | l -> l
+
+let _ = add_subst "SQLITE3_INCLUDES" (string_of_includes sqlite3_includes)
+let _ = add_subst "SQLITE3DIR" (List.hd sqlite3_includes)
+*)
+
 let _ =
   let prog = "assert Pcre.config_utf8;;" in
   let f mode =
@@ -976,29 +1015,21 @@ let _ =
   List.iter f modes
 
 
-let _ =
+let lablgtk_incs =
   match detect_lablgtk2 ~modes conf with
-    [], [] -> !fatal_error "Could not link with LablGtk2"
+    [], [] -> !fatal_error "Could not link with LablGtk2"; assert false
   | l, _ ->
       add_subst "LABLGTK2_INCLUDES" (string_of_includes l);
-      add_subst "LABLGTK2DIR" (List.hd l)
+      add_subst "LABLGTK2DIR" (List.hd l);
+      l
 
 let _ =
   let (incs,b) =
-    match detect_lablgtksourceview2 ~modes conf with
-      [], [] -> ("",false)
+    match detect_lablgtkextras ~modes lablgtk_incs conf with
+      [], [] -> !fatal_error "Could not link with LablGtk-extras"; assert false
     | l, _ -> (string_of_includes l,true)
   in
-  add_subst "LABLGTKSOURCEVIEW_INCLUDES" incs;
-  add_subst "USE_LABLGTKSOURCEVIEW" (if b then "yes" else "no");
-  add_subst "CAMTOP_SOURCEVIEW_MODULE"
-    (if b then "Camtop_sourceview" else "Camtop_textview");
-  add_subst "CAMTOP_SOURCEVIEW_MODULE_CMO"
-    (if b then "camtop_sourceview.cmo" else "camtop_textview.cmo");
-  add_subst "LABLGTKSOURCEVIEW_CMA"
-    (if b then "lablgtksourceview2.cma" else "");
-  add_subst "LABLGTKSOURCEVIEW_CMXA"
-    (if b then "lablgtksourceview2.cmxa" else "")
+  add_subst "LABLGTKEXTRAS_INCLUDES" incs
 
 let _ =
   match exec_and_get_first_line "pkg-config" [| "--cflags-only-I" ; "gtk+-2.0" |] with
